# loguru_configurable #

Wrapper that adds an [application_settings](https://github.com/StockwatchDev/application_settings) ConfigSection to
[loguru](https://github.com/Delgan/loguru), a library which aims to bring enjoyable logging in Python.

Also relies on [loguru-config](https://github.com/erezinman/loguru-config) and
[loguru-logging-intercept](https://github.com/MatthewScholefield/loguru-logging-intercept).
